summaryrefslogtreecommitdiffstats
path: root/kmplot/kmplot/kmplotio.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmplot/kmplot/kmplotio.h')
-rw-r--r--kmplot/kmplot/kmplotio.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmplot/kmplot/kmplotio.h b/kmplot/kmplot/kmplotio.h
index 3a92aa75..09112bbd 100644
--- a/kmplot/kmplot/kmplotio.h
+++ b/kmplot/kmplot/kmplotio.h
@@ -60,11 +60,11 @@ class KmPlotIO
private:
/** Esay way to add a tag to the Dom tree
* @param &doc The document.
* @param parentTag The parent tag to support encapsulated tags.
* @param tagName The Name of the tag.
* @param tagValue The data between the opening and cloding tag.
*/
- void addTag( TQDomDocument &doc, TQDomElement &parentTag, const TQString tagName, const TQString tagValue );
+ void addTag( TQDomDocument &doc, TQDomElement &tqparentTag, const TQString tagName, const TQString tagValue );
/// Reads axes parameters from the node @a n.
/// @param n Node containing the options.
void parseAxes( const TQDomElement &n );
@@ -60,11 +60,11 @@ class KmPlotIO
/** Esay way to add a tag to the Dom tree
* @param &doc The document.
- * @param parentTag The parent tag to support encapsulated tags.
+ * @param tqparentTag The tqparent tag to support encapsulated tags.
* @param tagName The Name of the tag.
* @param tagValue The data between the opening and cloding tag.